@@ -1,5 +1,5 @@
 package Mail::DMARC;
-our $VERSION = '1.20150317'; # VERSION
+our $VERSION = '1.20150527'; # VERSION
 use strict;
 use warnings;
 
@@ -290,7 +290,7 @@ Mail::DMARC - Perl implementation of DMARC
 
 =head1 VERSION
 
-version 1.20150317
+version 1.20150527
 
 =head1 SYNOPSIS
 
@@ -379,6 +379,8 @@ outgoing reports will have null values for report.uuid and report_record.count
 
 =for markdown [![Coverage Status](https://coveralls.io/repos/msimerson/mail-dmarc/badge.svg)](https://coveralls.io/r/msimerson/mail-dmarc)
 
+=for markdown [![Stories in Ready](https://badge.waffle.io/msimerson/mail-dmarc.png?label=ready&title=Ready)](https://waffle.io/msimerson/mail-dmarc)
+
 =head1 CLASSES
 
 L<Mail::DMARC> - the perl interface for DMARC
@@ -516,7 +518,7 @@ The dkim results can also be build iteratively by passing in key value pairs or
 
 Each hash or hashref is appended to the dkim array.
 
-Finally, you can pass a coderef which won't be called until the dkim method is used to read the dkim results.  It must return an array reference as described above.  As a convenience, your can return the result of calling C<< $dmarc->dkim_from_mail_dkim($dkim_verifier) >> to produce such an arrayref from a Mail::DKIM::Verifier object.
+Finally, you can pass a coderef which won't be called until the dkim method is used to read the dkim results.  It must return an array reference as described above.
 
 The dkim result is an array reference.
 
@@ -614,7 +616,7 @@ Davide Migliavacca <shari@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Benny Pedersen Marc Bradshaw Ricardo Signes
+=for stopwords Benny Pedersen Making GitHub Delicious. Marc Bradshaw Priyadi Iman Nurcahyo Ricardo Signes
 
 =over 4
 
@@ -624,10 +626,18 @@ Benny Pedersen <me@junc.eu>
 
 =item *
 
+Making GitHub Delicious. <iron@waffle.io>
+
+=item *
+
 Marc Bradshaw <marc@marcbradshaw.net>
 
 =item *
 
+Priyadi Iman Nurcahyo <priyadi@priyadi.net>
+
+=item *
+
 Ricardo Signes <rjbs@cpan.org>
 
 =item *
