@@ -1,5 +1,5 @@
 package Mail::DMARC::PurePerl;
-our $VERSION = '1.20150317'; # VERSION
+our $VERSION = '1.20150527'; # VERSION
 use strict;
 use warnings;
 
@@ -293,6 +293,7 @@ sub is_whitelisted {
 
 sub has_valid_reporting_uri {
     my ( $self, $rua ) = @_;
+    return unless $rua;
     my $recips_ref = $self->report->uri->parse($rua);
     my @has_permission;
     foreach my $uri_ref (@$recips_ref) {
@@ -312,10 +313,6 @@ sub get_dkim_pass_sigs {
 
     my $dkim_sigs = $self->dkim or return ();    # message not signed
 
-    if ( ref $dkim_sigs eq 'Mail::DKIM::Verifier' ) {
-        $dkim_sigs = $self->dkim_from_mail_dkim($dkim_sigs);
-    };
-
     if ( 'ARRAY' ne ref $dkim_sigs ) {
         croak "dkim needs to be an array reference!";
     }
@@ -562,7 +559,7 @@ Mail::DMARC::PurePerl - Pure Perl implementation of DMARC
 
 =head1 VERSION
 
-version 1.20150317
+version 1.20150527
 
 =head1 METHODS
 
